@@ -3,6 +3,7 @@ from typing import List, Optional
 from interactions import Channel, Guild, Member
 
 from .models import VoiceState
+from .player import Player
 
 
 @property
@@ -43,4 +44,13 @@ def guild_voice_states(self) -> Optional[List[VoiceState]]:
     ]
 
 
+@property
+def player(self) -> Optional[Player]:
+    """
+    Returns player of the guild.
+    """
+    return self._client._bot_var.lavalink_client.player_manager.get(int(self.id))
+
+
 Guild.voice_states = guild_voice_states
+Guild.player = player
